pub unsafe extern "C" fn spinBooleanGetValue(
hNode: spinNodeHandle,
pbValue: *mut bool8_t,
) -> spinErrorExpand description
Retrieves the value of a boolean node; boolean values are represented by ‘True’ (which equals ‘0’) and ‘False’ (which equals ‘1’) @see spinError
@param hNode The boolean node of the value to read @param pValue The boolean pointer in which the value is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error