pub unsafe extern "C" fn spinCameraGetNextImage(
hCamera: spinCamera,
phImage: *mut spinImage,
) -> spinErrorExpand description
Retrieves an image from a camera @see spinError
@param hCamera The camera of the image to retrieve @param phImage The image handle pointer in which the image is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error