pub unsafe extern "C" fn spinCameraGetNextImageEx(
hCamera: spinCamera,
grabTimeout: u64,
phImage: *mut spinImage,
) -> spinErrorExpand description
Retrieves an image from a camera; manually set the timeout in milliseconds @see spinError
@param hCamera The camera of the image to retrieve @param grabTimeout The timeout value for returned an image @param phImage The image handle pointer in which the image is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error