spinCameraGetTLDeviceNodeMap

Function spinCameraGetTLDeviceNodeMap 

pub unsafe extern "C" fn spinCameraGetTLDeviceNodeMap(
    hCamera: spinCamera,
    phNodeMap: *mut spinNodeMapHandle,
) -> spinError
Retrieves the transport layer device nodemap from a camera @see spinError

@param hCamera The camera from which the transport layer device nodemap is retrieved @param phNodeMap The nodemap handle pointer in which the nodemap is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error