spinCameraIsStreaming

Function spinCameraIsStreaming 

pub unsafe extern "C" fn spinCameraIsStreaming(
    hCamera: spinCamera,
    pbIsStreaming: *mut bool8_t,
) -> spinError
Checks whether a camera is currently acquiring images @see spinError

@param hCamera The camera to check @param pbIsStreaming The boolean pointer to return whether or not the camera is currently streaming

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error