pub unsafe extern "C" fn spinCameraListAppend(
hCameraListBase: spinCameraList,
hCameraListToAppend: spinCameraList,
) -> spinErrorExpand description
Appends all the cameras from one camera list to another @see spinError
@param hCameraListBase The camera list to receive the other @param hCameraListToAppend The camera list to add to the other
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error