pub unsafe extern "C" fn spinCameraListGetSize(
hCameraList: spinCameraList,
pSize: *mut size_t,
) -> spinErrorExpand description
Retrieves the number of cameras on a camera list @see spinError
@param hCameraList The camera list where the cameras to be counted are @param pSize The unsigned integer pointer in which the number of cameras is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error