spinCameraListRemoveBySerial

Function spinCameraListRemoveBySerial 

pub unsafe extern "C" fn spinCameraListRemoveBySerial(
    hCameraList: spinCameraList,
    pSerial: *const c_char,
) -> spinError
Removes a camera from a camera list using its serial number @see spinError

@param hCameraList The camera of the camera to remove @param pSerial The serial number of the camera to remove

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error