spinCategoryGetNumFeatures

Function spinCategoryGetNumFeatures 

pub unsafe extern "C" fn spinCategoryGetNumFeatures(
    hCategoryNode: spinNodeHandle,
    pValue: *mut size_t,
) -> spinError
Retrieves the number of a features (or child nodes) or a category node @see spinError

@param hCategoryNode The category node where the features to be counted are @param pValue The unsigned integer pointer in which the number of features is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error