pub unsafe extern "C" fn spinCategoryReleaseNode(
hCategoryNode: spinNodeHandle,
hFeature: spinNodeHandle,
) -> spinErrorExpand description
Releases the feature node from the category node. Make sure node handle is cleaned up properly by setting it to NULL after the node is released If this function is not explicitly called, the handle will be released upon the release of the camera handle. @see spinCameraRelease @see spinError
@param hCategoryNode The category node handle from which the feature node is retrieved @param hFeature The feature node handle to be released
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error