spinDeviceArrivalEventHandlerCreate

Function spinDeviceArrivalEventHandlerCreate 

pub unsafe extern "C" fn spinDeviceArrivalEventHandlerCreate(
    phDeviceArrivalEventHandler: *mut spinDeviceArrivalEventHandler,
    pFunction: spinArrivalEventFunction,
    pUserData: *mut c_void,
) -> spinError
Creates a device arrival event handler @see spinError

@param phDeviceArrivalEventHandler The device arrival event handler pointer in which the device arrival event context is created @param pFunction The function to be called at device event occurrences; signature to match: void(spinArrivalEventFunction)(void pUserData) @param pUserData Properties that can be passed into the event function

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error