spinDeviceEventGetId

Function spinDeviceEventGetId 

pub unsafe extern "C" fn spinDeviceEventGetId(
    hDeviceEventData: spinDeviceEventData,
    pEventId: *mut u64,
) -> spinError
Retrieves the event ID of a device event @see spinError

@param hDeviceEventData The log event data received from the log event @param pEventId The unsigned integer pointer in which the event ID is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error