pub unsafe extern "C" fn spinDeviceRemovalEventHandlerCreate(
phDeviceRemovalEventHandler: *mut spinDeviceRemovalEventHandler,
pFunction: spinRemovalEventFunction,
pUserData: *mut c_void,
) -> spinErrorExpand description
Creates a device removal event handler @see spinError
@param phDeviceRemovalEventHandler The device removal event handler pointer in which the device removal event context is created @param pFunction The function to be called at device event occurrences; signature to match: void(spinRemovalEventFunction)(uint64_t deviceSerialNumber, void pUserData)
@param pUserData Properties that can be passed into the event function
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error