pub unsafe extern "C" fn spinEnumerationEntryGetSymbolic(
hNode: spinNodeHandle,
pBuf: *mut c_char,
pBufLen: *mut size_t,
) -> spinErrorExpand description
Retrieves the symbolic of an entry node as a c-string @see spinError
@param hNode The entry node of the symbolic to retrieve @param pBuf The c-string character buffer in which the symbolic of the entry node is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error