pub unsafe extern "C" fn spinEnumerationGetCurrentEntry(
hEnumNode: spinNodeHandle,
phEntry: *mut spinNodeHandle,
) -> spinErrorExpand description
Retrieves the currently selected entry node from an enum node @see spinError
@param hEnumNode The enum node from which the current entry node is retrieved @param phEntry The node handle pointer in which the current entry node is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error