pub unsafe extern "C" fn spinEnumerationGetEntryByIndex(
hEnumNode: spinNodeHandle,
index: size_t,
phEntry: *mut spinNodeHandle,
) -> spinErrorExpand description
Retrieves an entry node from an enum node using an index @see spinError
@param hEnumNode The enum node from which the entry node is retrieved @param index The index of the entry node @param phEntry The node handle pointer in which the entry node is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error