pub unsafe extern "C" fn spinEnumerationReleaseNode(
hEnumNode: spinNodeHandle,
hEntry: spinNodeHandle,
) -> spinErrorExpand description
Releases the entry node from the enum node handle. Make sure node handle is cleaned up properly by setting it to NULL after the node is released If this function is not explicitly called, the handle will be released upon the release of the camera handle. @see spinCameraRelease @see spinError
@param hEnumNode The enum node from which the current entry node is retrieved @param hEntry The entry node handle to be released
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error