pub unsafe extern "C" fn spinEnumerationSetIntValue(
hEnumNode: spinNodeHandle,
value: i64,
) -> spinErrorExpand description
Sets a new entry using its integer value retrieved from a call to spinEnumerationEntryGetIntValue(); note that enumeration entry int and enum values are different - int values defined on camera, enum values found in SpinnakerDefsC.h @see spinEnumerationEntryGetIntValue() @see spinError
@param hEnumNode The enum node having its entry changed @param value The integer value of the entry node to set; this corresponds to the integer value internal to the camera
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error