spinErrorGetLast

Function spinErrorGetLast 

pub unsafe extern "C" fn spinErrorGetLast(
    pError: *mut spinError,
) -> spinError
Retrieves the error code of the last error @see spinError

@param pError The error enum pointer in which the error message is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error