spinErrorGetLastBuildTime

Function spinErrorGetLastBuildTime 

pub unsafe extern "C" fn spinErrorGetLastBuildTime(
    pBuf: *mut c_char,
    pBufLen: *mut size_t,
) -> spinError
Retrieves the build time of the last error @see spinError

@param pBuf The c-string character buffer in which the build time is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error