pub unsafe extern "C" fn spinErrorGetLastFunctionName(
pBuf: *mut c_char,
pBufLen: *mut size_t,
) -> spinErrorExpand description
Retrieves the function name of the last error @see spinError
@param pBuf The c-string character buffer in which the function name is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error