spinErrorGetLastLineNumber

Function spinErrorGetLastLineNumber 

pub unsafe extern "C" fn spinErrorGetLastLineNumber(
    pLineNum: *mut i64,
) -> spinError
Retrieves the line number of the last error @see spinError

@param pBuf The c-string character buffer in which the line number is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error