pub unsafe extern "C" fn spinFloatGetMin(
hNode: spinNodeHandle,
pValue: *mut f64,
) -> spinErrorExpand description
Retrieves the minimum value of a float node; all potential values must be greater than or equal to the minimum @see spinError
@param hNode The float node of the minimum value to retrieve @param pValue The double pointer in which the minimum value is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error