pub unsafe extern "C" fn spinFloatGetRepresentation(
hNode: spinNodeHandle,
pValue: *mut spinRepresentation,
) -> spinErrorExpand description
Retrieves the numerical representation of the value of a node; i.e. linear, logarithmic, hexidecimal, MAC address, etc. @see spinError
@param hNode The float node of the numerical representation to retrieve @param pValue The representation enum pointer in which the type of numerical representation is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error