spinFloatGetUnit

Function spinFloatGetUnit 

pub unsafe extern "C" fn spinFloatGetUnit(
    hNode: spinNodeHandle,
    pBuf: *mut c_char,
    pBufLen: *mut size_t,
) -> spinError
Retrieves the units of the float node value @see spinError

@param hNode The float node of the units to retrieve @param pBuf The c-string character buffer in which the value units are returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error