pub unsafe extern "C" fn spinFloatGetValue(
hNode: spinNodeHandle,
pValue: *mut f64,
) -> spinErrorExpand description
Retrieves the value of a float node @see spinError
@param hNode The float node of the value to read @param pValue The double pointer in which the value is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error