spinImageConvertEx

Function spinImageConvertEx 

pub unsafe extern "C" fn spinImageConvertEx(
    hSrcImage: spinImage,
    pixelFormat: spinPixelFormatEnums,
    algorithm: spinColorProcessingAlgorithm,
    hDestImage: spinImage,
) -> spinError
Converts the pixel format and color processing algorithm of one image into a new image @see spinError

@param hSrcImage The image to be converted @param pixelFormat The pixel format to be converted to @param algorithm The color processing algorithm to use for conversion @param hDestImage The image handle pointer in which the converted image is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error