spinImageCreateEx2

Function spinImageCreateEx2 

pub unsafe extern "C" fn spinImageCreateEx2(
    phImage: *mut spinImage,
    width: size_t,
    height: size_t,
    offsetX: size_t,
    offsetY: size_t,
    pixelFormat: spinPixelFormatEnums,
    pData: *mut c_void,
    dataPayloadType: spinPayloadTypeInfoIDs,
    dataSize: size_t,
) -> spinError
Creates an image with some set properties; images created this way must be destroyed

@see spinError @see spinImageGetTLPayloadType

@param phImage The image handle pointer in which the image is returned @param width The width to set @param height The height to set @param offsetX The offset along the X axis to set @param offsetY The offset along the Y axis to set @param pixelFormat The pixel format to set @param pData The image data to set; can be set to null @param dataPayloadType The payload type of the data. This value can be retrieved from an existing image by using the spinImageGetTLPayloadType() function call. @param dataSize The size of the provided data in bytes

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error