spinImageEventHandlerCreate

Function spinImageEventHandlerCreate 

pub unsafe extern "C" fn spinImageEventHandlerCreate(
    phImageEventHandler: *mut spinImageEventHandler,
    pFunction: spinImageEventFunction,
    pUserData: *mut c_void,
) -> spinError
Creates an image event handler @see spinError

@param phImageEventHandler The image event handler pointer in which the image event context is created @param pFunction The function to be called at image event occurrences; signature to match: void(spinImageEventFunction)(const spinImage hImage, void pUserData) @param pUserData Properties that can be passed into the event function

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error