pub unsafe extern "C" fn spinImageGetBitsPerPixel(
hImage: spinImage,
pBitsPerPixel: *mut size_t,
) -> spinErrorExpand description
Retrieves the number of bits per pixel of an image @see spinError
@param hImage The image to be saved @param pBitsPerPixel The unsigned integer pointer in which the number of bits per pixel is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error