pub unsafe extern "C" fn spinImageGetData(
hImage: spinImage,
ppData: *mut *mut c_void,
) -> spinErrorExpand description
Retrieves the image data of an image @see spinError
@param hImage The image of the image data to retrieve @param ppData The pointer to the void pointer in which the image data is retrieved
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error