spinImageGetPaddingX

Function spinImageGetPaddingX 

pub unsafe extern "C" fn spinImageGetPaddingX(
    hImage: spinImage,
    pPaddingX: *mut size_t,
) -> spinError
Retrieves the padding of an image along its X axis @see spinError

@param hImage The image of the padding along the X axis to retrieve @param pPaddingX The unsigned integer pointer in which the padding along the X axis is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error