spinImageGetPaddingY

Function spinImageGetPaddingY 

pub unsafe extern "C" fn spinImageGetPaddingY(
    hImage: spinImage,
    pPaddingY: *mut size_t,
) -> spinError
Retrieves the padding of an image along its Y axis @see spinError

@param hImage The image of the padding along the Y axis to retrieve @param pPaddingY The unsigned integer pointer in which the padding along the Y axis is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error