pub unsafe extern "C" fn spinImageGetPayloadType(
hImage: spinImage,
pPayloadType: *mut size_t,
) -> spinErrorExpand description
Retrieves the payload type of an image (as an enum, spinPayloadTypeInfoIds) @see spinError @see spinPayloadTypeInfoIds
@param hImage The image of the payload type to retrieve @param pPayloadType The payload type enum pointer in which the payload type is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error