pub unsafe extern "C" fn spinImageGetPixelFormat(
hImage: spinImage,
pPixelFormat: *mut spinPixelFormatEnums,
) -> spinErrorExpand description
Retrieves the pixel format of an image (as an enum, spinPixelFormatEnums) @see spinError @see spinPixelFormatEnums
@param hImage The image of the pixel format to retrieve @param pPixelFormat The pixel format enum pointer in which the pixel format is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error