spinImageGetTLPixelFormat

Function spinImageGetTLPixelFormat 

pub unsafe extern "C" fn spinImageGetTLPixelFormat(
    hImage: spinImage,
    pPixelFormat: *mut u64,
) -> spinError
Retrieves the transport layer pixel format of an image (as an unsigned integer) @see spinError

@param hImage The image of the TL pixel format to retrieve @param pPixelFormat The unsigned integer pointer in which the TL pixel format is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error