spinImageGetTimeStamp

Function spinImageGetTimeStamp 

pub unsafe extern "C" fn spinImageGetTimeStamp(
    hImage: spinImage,
    pTimeStamp: *mut u64,
) -> spinError
Retrieves the timestamp of an image @see spinError

@param hImage The image of the timestamp to retrieve @param pTimeStamp The unsigned integer pointer om which the timestamp is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error