spinImageGetValidPayloadSize

Function spinImageGetValidPayloadSize 

pub unsafe extern "C" fn spinImageGetValidPayloadSize(
    hImage: spinImage,
    pSize: *mut size_t,
) -> spinError
Retrieves the valid payload size of an image @see spinError

@param hImage The image of the payload size to retrieve @param pSize The unsigned integer pointer in which the size of the valid payload is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error