pub unsafe extern "C" fn spinImageGetWidth(
hImage: spinImage,
pWidth: *mut size_t,
) -> spinErrorExpand description
Retrieves the width of an image @see spinError
@param hImage The image of the width to retrieve @param pWidth The unsigned integer pointer in which the width is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error