spinImageReset

Function spinImageReset 

pub unsafe extern "C" fn spinImageReset(
    hImage: spinImage,
    width: size_t,
    height: size_t,
    offsetX: size_t,
    offsetY: size_t,
    pixelFormat: spinPixelFormatEnums,
) -> spinError
Resets an image with some set properties @see spinError

@param hImage The image to be reset @param width The width to be reset to @param height The height to be reset to @param offsetX The offset to be reset to along the X axis @param offsetY The offset to be reset to along the Y axis @param pixelFormat The pixel format to be reset to

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error