spinImageSave

Function spinImageSave 

pub unsafe extern "C" fn spinImageSave(
    hImage: spinImage,
    pFilename: *const c_char,
    format: spinImageFileFormat,
) -> spinError
Saves an image using a specified file format (using an enum, spinImageFileFormat) @see spinError @see spinImageFileFormat

@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @Param format The file format to use to save the image

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error