spinImageSaveBmp

Function spinImageSaveBmp 

pub unsafe extern "C" fn spinImageSaveBmp(
    hImage: spinImage,
    pFilename: *const c_char,
    pOption: *const spinBMPOption,
) -> spinError
Saves an image as a BMP image @see spinError

@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @param pOption The image options related to saving as BMP; includes whether to save as indexed 8-bit

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error