spinImageSaveFromExt

Function spinImageSaveFromExt 

pub unsafe extern "C" fn spinImageSaveFromExt(
    hImage: spinImage,
    pFilename: *const c_char,
) -> spinError
Saves an image using a specified file format (using the extension of the filename) @see spinError

@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension)

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error