pub unsafe extern "C" fn spinImageSaveJpeg(
hImage: spinImage,
pFilename: *const c_char,
pOption: *const spinJPEGOption,
) -> spinErrorExpand description
Saves an image as a JPEG image @see spinError
@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @param pOption The image options related to saving as JPEG; includes quality and whether to save as progressive
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error