spinImageSaveJpg2

Function spinImageSaveJpg2 

pub unsafe extern "C" fn spinImageSaveJpg2(
    hImage: spinImage,
    pFilename: *const c_char,
    pOption: *const spinJPG2Option,
) -> spinError
Saves an image as a JPEG 2000 image @see spinError

@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @param pOption The image options related to saving as JPEG 2000; includes quality

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error