pub unsafe extern "C" fn spinImageSavePgm(
hImage: spinImage,
pFilename: *const c_char,
pOption: *const spinPGMOption,
) -> spinErrorExpand description
Saves an image as an PGM image @see spinError
@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @param pOption The image options related to saving as PGM; includes whether to save as binary
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error