spinImageSaveTiff

Function spinImageSaveTiff 

pub unsafe extern "C" fn spinImageSaveTiff(
    hImage: spinImage,
    pFilename: *const c_char,
    pOption: *const spinTIFFOption,
) -> spinError
Saves an image as a TIFF image @see spinError

@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @param pOption The image options related to saving as TIFF; includes compression method

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error