spinImageSetNumDecompressionThreads

Function spinImageSetNumDecompressionThreads 

pub unsafe extern "C" fn spinImageSetNumDecompressionThreads(
    numThreads: c_uint,
) -> spinError
Sets the default number of threads used for image decompression during spinImageConvert(). The number of threads used is defaulted to be equal to one less than the number of concurrent threads supported by the system.

@param numThreads Number of parallel image decompression threads set to run

@see spinImageConvert()

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error