spinImageStatisticsEnableAll

Function spinImageStatisticsEnableAll 

pub unsafe extern "C" fn spinImageStatisticsEnableAll(
    hStatistics: spinImageStatistics,
) -> spinError
Enables all channels of an image statistics context @see spinError

@param hStatistics The image statistics context to enable all channels

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error