spinImageStatisticsEnableGreyOnly

Function spinImageStatisticsEnableGreyOnly 

pub unsafe extern "C" fn spinImageStatisticsEnableGreyOnly(
    hStatistics: spinImageStatistics,
) -> spinError
Disables all channels of an image statistics context except grey-scale @see spinError

@param hStatistics The image statistics context to enable only grey

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error