spinImageStatisticsEnableRgbOnly

Function spinImageStatisticsEnableRgbOnly 

pub unsafe extern "C" fn spinImageStatisticsEnableRgbOnly(
    hStatistics: spinImageStatistics,
) -> spinError
Disables all channels of an image statistics context except red, blue, and green @see spinError

@param hStatistics The image statistics context to enable only RGB

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error