spinImageStatisticsGetAll

Function spinImageStatisticsGetAll 

pub unsafe extern "C" fn spinImageStatisticsGetAll(
    hStatistics: spinImageStatistics,
    channel: spinStatisticsChannel,
    pRangeMin: *mut c_uint,
    pRangeMax: *mut c_uint,
    pPixelValueMin: *mut c_uint,
    pPixelValueMax: *mut c_uint,
    pNumPixelValues: *mut c_uint,
    pPixelValueMean: *mut f32,
    ppHistogram: *mut *mut c_int,
) -> spinError
Retrieves all available information of an image statistics channel @see spinError

@param hStatistics The image statistics context of the channel @param channel The channel of the information to retrieve @param pRangeMin The unsigned integer pointer in which the minimum value of the range is returned @param pRangeMax The unsigned integer pointer in which the maximum value of the range is returned @param pPixelValueMin The unsigned integer pointer in which the minimum pixel value of the range is returned @param pPixelValueMax The unsigned integer pointer in which the maximum pixel value of the range is returned @param pNumPixelValues The unsigned integer pointer in which the number of pixel values is returned @param pPixelValueMean The float pointer in which the mean pixel value is returned @param ppiHistogram The pointer to the pointer in which the histogram data is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error