pub unsafe extern "C" fn spinImageStatisticsGetChannelStatus(
hStatistics: spinImageStatistics,
channel: spinStatisticsChannel,
pbEnabled: *mut bool8_t,
) -> spinErrorExpand description
Checks whether an image statistics context is enabled @see spinError
@param hStatistics The image statistics context of the channel @param channel The channel to check @param pbEnabled The boolean pointer to return whether or not the channel is enabled
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error