spinImageStatisticsGetHistogram

Function spinImageStatisticsGetHistogram 

pub unsafe extern "C" fn spinImageStatisticsGetHistogram(
    hStatistics: spinImageStatistics,
    channel: spinStatisticsChannel,
    ppHistogram: *mut *mut c_int,
) -> spinError
Retrieves a histogram of an image statistics channel @see spinError

@param hStatistics The image statistics context of the channel @param channel The channel of the histogram to be returned @param pHistogram The pointer to the integer pointer in which the histogram data is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error