spinIntegerGetInc

Function spinIntegerGetInc 

pub unsafe extern "C" fn spinIntegerGetInc(
    hNode: spinNodeHandle,
    pValue: *mut i64,
) -> spinError
Retrieves the increment of an integer node; all possible values must be divisible by the increment @see spinError

@param hNode The integer node of the increment to retrieve @param pValue The integer pointer in which the increment is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error