pub unsafe extern "C" fn spinIntegerGetMin(
hNode: spinNodeHandle,
pValue: *mut i64,
) -> spinErrorExpand description
Retrieves the minimum value of an integer node; all potential values must be greater than or equal to the minimum @see spinError
@param hNode The integer node of the minimum value to retrieve @param pValue The integer pointer in which the minimum value is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error