spinIntegerGetValueEx

Function spinIntegerGetValueEx 

pub unsafe extern "C" fn spinIntegerGetValueEx(
    hNode: spinNodeHandle,
    bVerify: bool8_t,
    pValue: *mut i64,
) -> spinError
Retrieves the value of an integer node; manually set whether to verify the node @see spinError

@param hNode The integer node of the value to read @param bVerify The boolean of whether to verify the node @param pValue The integer pointer in which the value is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error