spinInterfaceGetCameras

Function spinInterfaceGetCameras 

pub unsafe extern "C" fn spinInterfaceGetCameras(
    hInterface: spinInterface,
    hCameraList: spinCameraList,
) -> spinError
Retrieves a camera list from an interface; camera lists must be created and destroy

@see spinCameraListCreateEmpty() @see spinCameraListDestroy() @see spinError

@param hInterface The interface of the camera list to retrieve @param hCameraList The camera list to house the cameras from the interface

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error