pub unsafe extern "C" fn spinInterfaceGetCamerasEx(
hInterface: spinInterface,
bUpdateCameras: bool8_t,
hCameraList: spinCameraList,
) -> spinErrorExpand description
Retrieves a camera list from an interface; manually set whether to update the cameras; camera lists must be created and destroyed
@see spinCameraListCreateEmpty() @see spinCameraListDestroy() @see spinError
@param hInterface The interface of the camera list to retrieve @param bUpdateCameras The boolean of whether or not to update the cameras @param hCameraList The camera list to house the cameras from the interface
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error