spinInterfaceListGetSize

Function spinInterfaceListGetSize 

pub unsafe extern "C" fn spinInterfaceListGetSize(
    hInterfaceList: spinInterfaceList,
    pSize: *mut size_t,
) -> spinError
Retrieves the number of interfaces in an interface list @see spinError

@param hInterfaceList The interface list where the interfaces to be counted are @param pSize The unsigned integer pointer in which the number of interfaces is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error @see spinError