spinInterfaceRegisterDeviceArrivalEventHandler

Function spinInterfaceRegisterDeviceArrivalEventHandler 

pub unsafe extern "C" fn spinInterfaceRegisterDeviceArrivalEventHandler(
    hInterface: spinInterface,
    hDeviceArrivalEventHandler: spinDeviceArrivalEventHandler,
) -> spinError
Registers a device arrival event handler on an interface (event handlers registered in this way must be unregistered) @see spinError

@param hInterface The interface on which to register the device arrival event handler @param hDeviceArrivalEventHandler The device arrival event handler to register

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error