spinInterfaceSendActionCommand

Function spinInterfaceSendActionCommand 

pub unsafe extern "C" fn spinInterfaceSendActionCommand(
    hInterface: spinInterface,
    iDeviceKey: size_t,
    iGroupKey: size_t,
    iGroupMask: size_t,
    iActionTime: size_t,
    piResultSize: *mut size_t,
    results: *mut actionCommandResult,
) -> spinError
Broadcast an Action Command to all devices on interface @see spinError

@param iDeviceKey The Action Command’s device key @param iGroupKey The Action Command’s group key @param iGroupMask The Action Command’s group mask @param iActionTime (Optional) Time when to assert a future action. Zero means immediate action. @param piResultSize (Optional) The number of results in the results array. The value passed should be equal to the expected number of devices that acknowledge the command. Returns the number of received results. @param results (Optional) An Array with *piResultSize elements to hold the action command result status. The buffer is filled starting from index 0. If received results are less than expected number of devices that acknowledge the command, remaining results are not changed. If received results are more than expected number of devices that acknowledge the command, extra results are ignored and not appended to array. This parameter is ignored if piResultSize is 0. Thus this parameter can be NULL if pResultSize is 0 or NULL.

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error