pub unsafe extern "C" fn spinInterfaceUnregisterDeviceArrivalEventHandler(
hInterface: spinInterface,
hDeviceArrivalEventHandler: spinDeviceArrivalEventHandler,
) -> spinErrorExpand description
Unregisters a device arrival event handler from an interface @see spinError
@param hInterface The interface from which to unregister the device arrival event handler @param hDeviceArrivalEventHandler The device arrival event handler to unregister
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error