pub unsafe extern "C" fn spinInterfaceUnregisterDeviceRemovalEventHandler(
hInterface: spinInterface,
hDeviceRemovalEventHandler: spinDeviceRemovalEventHandler,
) -> spinErrorExpand description
Unregisters a device removal event handler from an interface @see spinError
@param hInterface The interface from which to unregister the device removal event handler @param hDeviceRemovalEventHandler The device removal event handler to unregister
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error