spinLogDataGetPriority

Function spinLogDataGetPriority 

pub unsafe extern "C" fn spinLogDataGetPriority(
    hLogEventData: spinLogEventData,
    pValue: *mut i64,
) -> spinError
Retrieves the priority of a log event @see spinError

@param hLogEventData The log event data received from the log event @param pValue The integer pointer in which the priority value is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error