spinLogDataGetTimestamp

Function spinLogDataGetTimestamp 

pub unsafe extern "C" fn spinLogDataGetTimestamp(
    hLogEventData: spinLogEventData,
    pBuf: *mut c_char,
    pBufLen: *mut size_t,
) -> spinError
Retrieves the timestamp of a log event @see spinError

@param hLogEventData The log event data received from the log event @param pBuf The c-string character buffer in which the timestamp of the log event is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error