spinNodeFromString

Function spinNodeFromString 

pub unsafe extern "C" fn spinNodeFromString(
    hNode: spinNodeHandle,
    pBuf: *const c_char,
) -> spinError
Sets the value of any node type from a c-string; it is important to ensure that the value of the c-string is appropriate to the node type @see spinError

@param hNode The node having its value changed @param pBuf The c-string of the value to set

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error