pub unsafe extern "C" fn spinNodeFromStringEx(
hNode: spinNodeHandle,
bVerify: bool8_t,
pBuf: *const c_char,
) -> spinErrorExpand description
Sets the value of any node type from a c-string; manually set whether to verify the node; ensure the value of the c-string is appropriate to the node type @see spinError
@param hNode The node having its value changed @param bVerify The boolean of whether to verify the node @param pBuf The c-string of the value to set
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error