pub unsafe extern "C" fn spinNodeGetCachingMode(
hNode: spinNodeHandle,
pCachingMode: *mut spinCachingMode,
) -> spinErrorExpand description
Retrieves the caching mode of a node (as an enum, spinCachingMode) @see spinError @see spinCachingMode
@param hNode The node of the caching mode to retrieve @param pCachingMode The caching mode enum pointer in which the caching mode is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error