pub unsafe extern "C" fn spinNodeGetDescription(
hNode: spinNodeHandle,
pBuf: *mut c_char,
pBufLen: *mut size_t,
) -> spinErrorExpand description
Retrieves a longer description of a node @see spinError
@param hNode The node of the description to retrieve @param pBuf The c-string character buffer in which the longer descrition of the node is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error