pub unsafe extern "C" fn spinNodeGetDisplayName(
hNode: spinNodeHandle,
pBuf: *mut c_char,
pBufLen: *mut size_t,
) -> spinErrorExpand description
Retrieves the display name of a node (whitespace possible) @see spinError
@param hNode The node of the display name to retrieve @param pBuf The c-string character buffer in which the display name of the node is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error