spinNodeGetPollingTime

Function spinNodeGetPollingTime 

pub unsafe extern "C" fn spinNodeGetPollingTime(
    hNode: spinNodeHandle,
    pPollingTime: *mut i64,
) -> spinError
Retrieve the polling time of a node @see spinError

@param hNode The node of the polling time to retrieve @param pPollingTime The integer pointer in which the polling time is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error