spinNodeMapGetNode

Function spinNodeMapGetNode 

pub unsafe extern "C" fn spinNodeMapGetNode(
    hNodeMap: spinNodeMapHandle,
    pName: *const c_char,
    phNode: *mut spinNodeHandle,
) -> spinError
Retrieves a node from the nodemap by name @see spinError

@param hNodeMap The node map where the node is @param pName The name of the node @param phNode The node handle pointer in which the node is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error