spinNodeMapReleaseNode

Function spinNodeMapReleaseNode 

pub unsafe extern "C" fn spinNodeMapReleaseNode(
    hNodeMap: spinNodeMapHandle,
    hNode: spinNodeHandle,
) -> spinError
Releases the entry node handle. Make sure node handle is cleaned up properly by setting it to NULL after the node is released. If this function is not explicitly called, the handle will be released upon the release of the camera handle. @see spinCameraRelease @see spinError

@param hNodeMap The node map from which the node handle is retrieved @param hNode The node handle to be released

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error