spinRegisterGet

Function spinRegisterGet 

pub unsafe extern "C" fn spinRegisterGet(
    hNode: spinNodeHandle,
    pBuf: *mut u8,
    length: i64,
) -> spinError
Retrieves the value of a register node @see spinError

@param hNode The register node of the value to retrieve @param pBuf The unsigned integer buffer in which the value is returned @param length The integer pointer in which the length of the register array is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error