spinRegisterGetEx

Function spinRegisterGetEx 

pub unsafe extern "C" fn spinRegisterGetEx(
    hNode: spinNodeHandle,
    bVerify: bool8_t,
    bIgnoreCache: bool8_t,
    pBuf: *mut u8,
    length: i64,
) -> spinError
Retrieves the value of a register node; manually set whether to verify the node and whether to ignore the cache @see spinError

@param hNode The register node of the value to retrieve @param bVerify The boolean of whether to verify the node @param IgnoreCache The boolean of whether to ignore the cache @param pBuf The unsigned integer buffer in which the value is returned @param length The integer pointer in which the length of the register array is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error