spinRegisterGetLength

Function spinRegisterGetLength 

pub unsafe extern "C" fn spinRegisterGetLength(
    hNode: spinNodeHandle,
    pLength: *mut i64,
) -> spinError
Retrieves the length (in bytes) of the value of a register node @see spinError

@param hNode The register node of the length to retrieve @param plength The integer in which the number of bytes is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error