spinRegisterSetEx

Function spinRegisterSetEx 

pub unsafe extern "C" fn spinRegisterSetEx(
    hNode: spinNodeHandle,
    bVerify: bool8_t,
    pBuf: *const u8,
    length: i64,
) -> spinError
Sets the value of a register node; manually set whether to verify the node @see spinError

@param hNode The register node of the value to set @param bVerify The boolean of whether to verify the node @param pBuf The unsigned integer buffer of the value to set @param length The number of bytes of the value to set

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error