spinStringGetValueEx

Function spinStringGetValueEx 

pub unsafe extern "C" fn spinStringGetValueEx(
    hNode: spinNodeHandle,
    bVerify: bool8_t,
    pBuf: *mut c_char,
    pBufLen: *mut size_t,
) -> spinError
Retrieves the value of a string node as a cstring; manually set whether to verify the node @see spinError

@param hNode The string node of the value to read @param bVerify The boolean of whether to verify the node @param pBuf The c-string character buffer in which the value of the node is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error