spinStringSetValueEx

Function spinStringSetValueEx 

pub unsafe extern "C" fn spinStringSetValueEx(
    hNode: spinNodeHandle,
    bVerify: bool8_t,
    pBuf: *const c_char,
) -> spinError
Sets the value of a string node; manually set whether to verify the node @see spinError

@param hNode The string node having its value changed @param bVerify The boolean of whether to verify the node @param pBuf The c-string of the value to set

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error