pub unsafe extern "C" fn spinSystemGetCamerasEx(
hSystem: spinSystem,
bUpdateInterfaces: bool8_t,
bUpdateCameras: bool8_t,
hCameraList: spinCameraList,
) -> spinErrorExpand description
Retrieves a list of detected (and enumerable) cameras on the system; manually set whether to update the current interface and camera lists; camera lists must be created and destroyed
@see spinCameraListCreateEmpty() @see spinCameraListDestroy() @see spinError
@param hSystem The system, from which the camera list is retrieved @param bUpdateInterfaces The boolean of whether to update the interface list @param bUpdateCameras The boolean of whether to update the camera list @param hCameraList The camera list to house the cameras from the system
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error