spinSystemGetInstance

Function spinSystemGetInstance 

pub unsafe extern "C" fn spinSystemGetInstance(
    phSystem: *mut spinSystem,
) -> spinError
Retrieves an instance of the system object; the system is a singleton, so there will only ever be one instance; system instance must be destroyed by calling spinSystemReleaseInstance

@see spinSystemReleaseInstance @see spinError

@param phSystem The system handle pointer in which the system instance is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error