spinSystemGetLoggingLevel

Function spinSystemGetLoggingLevel 

pub unsafe extern "C" fn spinSystemGetLoggingLevel(
    hSystem: spinSystem,
    pLogLevel: *mut spinnakerLogLevel,
) -> spinError
Retrieves the logging level for all logging events on the system @see spinError

@param hSystem The system, from which the logging level is retrieved @param logLevel The logging level enum pointer in which the current logging level is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error