spinSystemIsInUse

Function spinSystemIsInUse 

pub unsafe extern "C" fn spinSystemIsInUse(
    hSystem: spinSystem,
    pbIsInUse: *mut bool8_t,
) -> spinError
Checks whether a system is currently in use @see spinError

@param hSystem The system to check @param pbIsInUse The boolean pointer to return whether the system is currently in use

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error