pub unsafe extern "C" fn spinSystemRegisterInterfaceEventHandler(
hSystem: spinSystem,
hInterfaceEventHandler: spinInterfaceEventHandler,
) -> spinErrorExpand description
Registers an interface event handler (device arrival and device removal) to every interface on the system (interface events registered this way must be unregistered) If new interfaces are detected by the system after spinSystemRegisterInterfaceEventHandler() is called, those interfaces will be automatically registered with this event. @see spinError @see spinInterfaceEventHandler
@param hSystem The system, on which the interface event handler is registered @param hInterfaceEventHandler The interface event handler (device arrival and device removal) to register on the system
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error