spinSystemSetLoggingLevel

Function spinSystemSetLoggingLevel 

pub unsafe extern "C" fn spinSystemSetLoggingLevel(
    hSystem: spinSystem,
    logLevel: spinnakerLogLevel,
) -> spinError
Sets the logging level for all logging events on the system @see spinError

@param hSystem The system, on which the logging level is set @param logLevel The logging level to set

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error