spinSystemUnregisterDeviceArrivalEventHandler

Function spinSystemUnregisterDeviceArrivalEventHandler 

pub unsafe extern "C" fn spinSystemUnregisterDeviceArrivalEventHandler(
    hSystem: spinSystem,
    hDeviceArrivalEventHandler: spinDeviceArrivalEventHandler,
) -> spinError
Unregisters a device arrival event handler from the system @see spinError @see spinDeviceArrivalEventHandler

@param hSystem The system, from which the device arrival event handler is unregistered @param hDeviceArrivalEventHandler The device arrival event handler to unregister from the system

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error