spinSystemUnregisterDeviceRemovalEventHandler

Function spinSystemUnregisterDeviceRemovalEventHandler 

pub unsafe extern "C" fn spinSystemUnregisterDeviceRemovalEventHandler(
    hSystem: spinSystem,
    hDeviceRemovalEventHandler: spinDeviceRemovalEventHandler,
) -> spinError
Unregisters a device removal event handler from the system @see spinError @see spinDeviceRemovalEventHandler

@param hSystem The system, from which the device removal event handler is unregistered @param hDeviceRemovalEventHandler The device removal event handler to unregister from the system

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error