spinSystemUpdateCameras

Function spinSystemUpdateCameras 

pub unsafe extern "C" fn spinSystemUpdateCameras(
    hSystem: spinSystem,
    pbChanged: *mut bool8_t,
) -> spinError
Updates the list of cameras on the system, informing whether there has been any changes @see spinError

@param hSystem The system, on which the list of attached cameras is updated @param pbChanged The boolean pointer to return whether cameras have arrived on or been removed from the system

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error