spinSystemUpdateCamerasEx

Function spinSystemUpdateCamerasEx 

pub unsafe extern "C" fn spinSystemUpdateCamerasEx(
    hSystem: spinSystem,
    bUpdateInterfaces: bool8_t,
    pbChanged: *mut bool8_t,
) -> spinError
Updates the list of cameras on the system, informing whether there has been any changes; manually set whether to update the current interface lists @see spinError

@param hSystem The system, on which the list of attached cameras is updated @param bUpdateInterfaces The boolean of whether to update the interface list @param pbChanged The boolean pointer to return whether cameras have arrived or been removed from the system

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error