_spinPixelFormatNamespaceID

Type Alias _spinPixelFormatNamespaceID 

pub type _spinPixelFormatNamespaceID = c_uint;
This enum represents the namespace in which the TL specific pixel format resides. This enum is returned from a captured image when calling spinImageGetTLPixelFormatNamespace(). It can be used to interpret the raw pixel format returned from spinImageGetTLPixelFormat().

@see spinImageGetTLPixelFormat()

@see spinImageGetTLPixelFormatNamespace()