_spinXMLValidation

Type Alias _spinXMLValidation 

pub type _spinXMLValidation = c_uint;
! typedef describing the different validity checks which can be performed on an XML file *! The enum values for a bitfield of lenght uint32_t */