pub unsafe extern "C" fn spinCameraIsValid(
hCamera: spinCamera,
pbValid: *mut bool8_t,
) -> spinErrorExpand description
Checks whether a camera is still valid for use @see spinError
@param hCamera The camera to check @param pbValid The boolean pointer to return whether or not the camera is valid
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error