pub unsafe extern "C" fn spinCameraListGetBySerial(
hCameraList: spinCameraList,
pSerial: *const c_char,
phCamera: *mut spinCamera,
) -> spinErrorExpand description
Retrieves a camera from a camera list using its serial number. This function will return a NULL spinCamera pointer if no matching camera serial is found. @see spinError
@param hCameraList The camera list of the camera to retrieve @param serial The serial number of the camera to retrieve @param phCamera The camera handle pointer in which the camera is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error