spinCameraListRemove

Function spinCameraListRemove 

pub unsafe extern "C" fn spinCameraListRemove(
    hCameraList: spinCameraList,
    index: size_t,
) -> spinError
Removes a camera from a camera list using its index @see spinError

@param hCameraList The camera list of the camera to remove @param index The index of the camera to remove

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error