spinCameraRegisterDeviceEventHandlerEx

Function spinCameraRegisterDeviceEventHandlerEx 

pub unsafe extern "C" fn spinCameraRegisterDeviceEventHandlerEx(
    hCamera: spinCamera,
    hDeviceEventHandler: spinDeviceEventHandler,
    pName: *const c_char,
) -> spinError
Registers a specific device event handler (only one device event type) to a camera @see spinError

@param hCamera The camera on which to register the specific device event handler @param hDeviceEventHandler The device event handler to register @param pName The name of the device event handler to register

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error