pub unsafe extern "C" fn spinCommandIsDone(
hNode: spinNodeHandle,
pbValue: *mut bool8_t,
) -> spinErrorExpand description
Retrieves whether or not the action of a command node has completed @see spinError
@param hNode The command node to check @param pValue The boolean pointer to return whether or not the command has completed
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error