pub unsafe extern "C" fn spinDeviceEventGetPayloadDataSize(
hDeviceEventData: spinDeviceEventData,
pBufSize: *mut size_t,
) -> spinErrorExpand description
Retrieves the payload data size of a device event @see spinError
@param hDeviceEventData The log event data received from the log event @param pBufSize The unsigned integer pointer in which the size of the payload is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error