pub unsafe extern "C" fn spinEnumerationGetNumEntries(
hEnumNode: spinNodeHandle,
pValue: *mut size_t,
) -> spinErrorExpand description
Retrieves the number of entries of an enum node @see spinError
@param hEnumNode The enum node where the entries to be counted are @param pValue The unsigned integer pointer in which the number of entries is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error