pub unsafe extern "C" fn spinEnumerationSetEnumValue(
hEnumNode: spinNodeHandle,
value: size_t,
) -> spinErrorExpand description
Sets a new entry using its enum; note that enumeration entry int and enum values are different - int values defined on camera, enum values found in SpinnakerDefsC.h @see spinEnumerationEntryGetEnumValue() @see spinError
@param hEnumNode The enum node have its entry changed @param value The enum value of the entry node to set; this corresponds to its integer value created in the library
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error