pub unsafe extern "C" fn spinFloatGetMax(
hNode: spinNodeHandle,
pValue: *mut f64,
) -> spinErrorExpand description
Retrieves the maximum value of a float node; all potential values must be lesser than or equal to the maximum @see spinError
@param hNode The float node of the maximum value to retrieve @param pValue The double pointer in which the maximum value is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error