pub unsafe extern "C" fn spinFloatSetValueEx(
hNode: spinNodeHandle,
bVerify: bool8_t,
value: f64,
) -> spinErrorExpand description
Sets the value of a float node; manually set whether to verify the node @see spinError
@param hNode The float node having its value changed @param bVerify The boolean of whether to verify the node @param value The float value to set
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error