pub unsafe extern "C" fn spinImageConvert(
hSrcImage: spinImage,
pixelFormat: spinPixelFormatEnums,
hDestImage: spinImage,
) -> spinErrorExpand description
Converts the pixel format of one image into a new image @see spinError
@param hSrcImage The image to be converted @param pixelFormat The pixel format to be converted to @param hDestImage The image handle pointer in which the converted image is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error