pub unsafe extern "C" fn spinImageDeepCopy(
hSrcImage: spinImage,
hDestImage: spinImage,
) -> spinErrorExpand description
Creates a deep copy of an image (the destination image must be created as an empty image prior to the deep copy) @see spinError
@param hSrcImage The image to be copied @param hDestImage The image handle in which the image is copied
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error