pub unsafe extern "C" fn spinImageGetBufferSize(
hImage: spinImage,
pSize: *mut size_t,
) -> spinErrorExpand description
Retrieves the buffer size of an image @see spinError
@param hImage The image of image data buffer to retrieve @param pSize The unsigned integer pointer in which the size of the image data if returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error