pub unsafe extern "C" fn spinImageGetHeight(
hImage: spinImage,
pHeight: *mut size_t,
) -> spinErrorExpand description
Retrieves the height of an image @see spinError
@param hImage The image of the height to retrieve @param pHeight The unsigned integer pointer in which the height is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error