spinImageGetNumDecompressionThreads

Function spinImageGetNumDecompressionThreads 

pub unsafe extern "C" fn spinImageGetNumDecompressionThreads(
    pNumThreads: *mut c_uint,
) -> spinError
Gets the number of threads used for image decompression during Convert().

@param pNumThreads The pointer indicating the number of parallel image decompression threads set to run

@see spinImageSetNumDecompressionThreads()

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error