pub unsafe extern "C" fn spinImageGetOffsetX(
hImage: spinImage,
pOffsetX: *mut size_t,
) -> spinErrorExpand description
Retrieves the offset of an image along its X axis @see spinError
@param hImage The image of the offset along the X axis to retrieve @param pOffsetX The unsigned integer pointer in which the offset along the X axis is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error