pub unsafe extern "C" fn spinImageGetStatusDescription(
status: spinImageStatus,
pBuf: *mut c_char,
pBufLen: *mut size_t,
) -> spinErrorExpand description
Retrieves the description of image status @see spinError
@param status The status enum @param pBuf The c-string character buffer in which the explanation of image status enum is returned @param pBufLen The unsigned integer pointer in which the length of the c-string is returned; the input value is the maximum length; if pBuf is NULL, minimum length of string buffer is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error