pub unsafe extern "C" fn spinImageSavePng(
hImage: spinImage,
pFilename: *const c_char,
pOption: *const spinPNGOption,
) -> spinErrorExpand description
Saves an image as a PNG image @see spinError
@param hImage The image to be saved @param pFilename The filename to use to save the image (with or without the appropriate file extension) @param pOption The image options related to saving as PNG; includes compression level and whether to save as interlaced
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error