pub unsafe extern "C" fn spinImageStatisticsEnableAll(
hStatistics: spinImageStatistics,
) -> spinErrorExpand description
Enables all channels of an image statistics context @see spinError
@param hStatistics The image statistics context to enable all channels
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error