pub unsafe extern "C" fn spinImageStatisticsEnableHslOnly(
hStatistics: spinImageStatistics,
) -> spinErrorExpand description
Disables all channels of an image statistics context except hue, saturation, and lightness @see spinError
@param hStatistics The image statistics context to enable only HSL
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error