spinImageStatisticsGetPixelValueRange

Function spinImageStatisticsGetPixelValueRange 

pub unsafe extern "C" fn spinImageStatisticsGetPixelValueRange(
    hStatistics: spinImageStatistics,
    channel: spinStatisticsChannel,
    pMin: *mut c_uint,
    pMax: *mut c_uint,
) -> spinError
Retrieves the pixel value range of an image statistics channel @see spinError

@param hStatistics The image statistics context of the channel @param channel The channel of the pixel value range to retrieve @param pMin The unsigned integer pointer in which the minimum value of the pixel value range is returned @param pMax The unsigned integer pointer in which the maximum value of the pixel value range is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error