pub unsafe extern "C" fn spinImageStatisticsSetChannelStatus(
hStatistics: spinImageStatistics,
channel: spinStatisticsChannel,
bEnable: bool8_t,
) -> spinErrorExpand description
Sets the status of an image statistics channel @see spinError
@param hStatistics The image statistics context of the channel @param channel The channel to enable/disable @param bEnable The boolean value to set; true enables, false disables
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error