pub unsafe extern "C" fn spinIntegerGetMax(
hNode: spinNodeHandle,
pValue: *mut i64,
) -> spinErrorExpand description
Retrieves the maximum value of an integer node; all potential values must be lesser than or equal to the maximum @see spinError
@param hNode The integer node of the maximum value to retrieve @param pValue The integer pointer in which the maximum value is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error