spinInterfaceGetTLNodeMap

Function spinInterfaceGetTLNodeMap 

pub unsafe extern "C" fn spinInterfaceGetTLNodeMap(
    hInterface: spinInterface,
    phNodeMap: *mut spinNodeMapHandle,
) -> spinError
Retrieves the transport layer nodemap from an interface @see spinError

@param hInterface The interface of the nodemap to retrieve @param phNodeMap The nodemap handle pointer in which the transport layer interface nodemap is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error