pub unsafe extern "C" fn spinInterfaceUpdateCameras(
hInterface: spinInterface,
pbChanged: *mut bool8_t,
) -> spinErrorExpand description
Checks whether any cameras have been connected or disconnected on an interface @see spinError
@param hInterface The interface of the list of attached cameras to update @param pbChanged The boolean pointer to return whether or not the cameras have changed
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error