pub unsafe extern "C" fn spinLogEventHandlerCreate(
phLogEventHandler: *mut spinLogEventHandler,
pFunction: spinLogEventFunction,
pUserData: *mut c_void,
) -> spinErrorExpand description
Creates a log event handler @see spinError
@param phLogEventHandler The log event handler pointer in which the log event context is created @param pFunction The function to be called at device event occurrences; signature to match: void(spinLogEventFunction)(const spinLogEventData hEventData, void pUserData) @param pUserData Properties that can be passed into the event function
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error