spinNodeMapGetNodeByIndex

Function spinNodeMapGetNodeByIndex 

pub unsafe extern "C" fn spinNodeMapGetNodeByIndex(
    hNodeMap: spinNodeMapHandle,
    index: size_t,
    phNode: *mut spinNodeHandle,
) -> spinError
Retrieves a node from the nodemap by index @see spinError

@param hNodeMap The node map where the node is @param index The index of the node @param phNode The node handle pointer in which the node is returned

@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error