pub unsafe extern "C" fn spinNodeMapGetNumNodes(
hNodeMap: spinNodeMapHandle,
pValue: *mut size_t,
) -> spinErrorExpand description
Gets the number of nodes in the map @see spinError
@param hNodeMap The node map where the nodes to be counted are @param pValue The unsigned integer pointer in which the number of nodes is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error