pub unsafe extern "C" fn spinNodeRegisterCallback(
hNode: spinNodeHandle,
pCbFunction: spinNodeCallbackFunction,
phCb: *mut spinNodeCallbackHandle,
) -> spinErrorExpand description
Registers a callback to a node @see spinError
@param hNode The node on which to register the callback @param pCbFunction The function pointer of the function that will execute when the callback is triggered; must match signature “void spinNodeCallbackFunction(spinNodeHandle hNode)” @param phCb The callback handle pointer in which the callback is returned; used to unregister callbacks
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error