pub unsafe extern "C" fn spinStringGetMaxLength(
hNode: spinNodeHandle,
pValue: *mut i64,
) -> spinErrorExpand description
Retrieves the maximum length of the c-string to be returned @see spinError
@param hNode The string node of the length to retrieve @param pValue The integer pointer in which the maximum length of the c-string is returned
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error