pub unsafe extern "C" fn spinSystemGetInterfaces(
hSystem: spinSystem,
hInterfaceList: spinInterfaceList,
) -> spinErrorExpand description
Retrieves a list of detected (and enumerable) interfaces on the system; interface lists must be created and destroyed
@see spinInterfaceListCreateEmpty() @see spinInterfaceListDestroy() @see spinError
@param hSystem The system, from which the interface list is retrieved @param hInterfaceList The interface list to house the interfaces from the system
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error