pub unsafe extern "C" fn spinSystemRegisterDeviceRemovalEventHandler(
hSystem: spinSystem,
hDeviceRemovalEventHandler: spinDeviceRemovalEventHandler,
) -> spinErrorExpand description
Registers a device removal event handler to the system to every interface on the system (event handlers registered this way must be unregistered) @see spinError
@param hSystem The system, on which the device removal event handler is registered @param hDeviceRemovalEventHandler The device removal event handler to register on the system
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error