pub unsafe extern "C" fn spinSystemReleaseInstance(
hSystem: spinSystem,
) -> spinErrorExpand description
Releases the system; make sure handle is cleaned up properly by setting it to NULL after system is released; the handle can only be used again after calling spinSystemGetInstance
@see spinSystemGetInstance @see spinError
@param hSystem The system handle
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error