pub unsafe extern "C" fn spinSystemUnregisterAllLogEventHandlers(
hSystem: spinSystem,
) -> spinErrorExpand description
Unregisters all logging event handlers from the system @see spinError
@param hSystem The system, from which all logging event handlers are unregistered
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error