pub unsafe extern "C" fn spinSystemUnregisterInterfaceEventHandler(
hSystem: spinSystem,
hInterfaceEventHandler: spinInterfaceEventHandler,
) -> spinErrorExpand description
Unregisters an interface event handler from the system @see spinError @see spinInterfaceEventHandler
@param hSystem The system, from which the interface event handler is unregistered @param hInterfaceEventHandler The interface event handler (device arrival and device removal) to unregister from the system
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error