pub unsafe extern "C" fn spinSystemUnregisterLogEventHandler(
hSystem: spinSystem,
hLogEventHandler: spinLogEventHandler,
) -> spinErrorExpand description
Unregisters a selected logging event handler from the system @see spinError
@param hSystem The system, from which the logging event handler is unregistered @param hLogEventHandler The logging event handler to unregister from the system
@return spinError The error code; returns SPINNAKER_ERR_SUCCESS (or 0) for no error